@@ -1,7 +1,9 @@
 """Common utils for Lakshmi."""
 
-def FormatMoney(x):
+
+def format_money(x):
     return '${:,.2f}'.format(x)
 
-def FormatMoneyDelta(x):
+
+def format_money_delta(x):
     return '{}${:,.2f}'.format('-' if x < 0 else '+', abs(x))
